window.Gleam.initSearch([{"doc":"comet","title":"comet","content":"# comet\n\n[![Package Version](https://img.shields.io/hexpm/v/comet)](https://hex.pm/packages/comet)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/comet/)\n\n✨Create a gleaming trail of application logs✨\n\nThe API of this library is still unstable. Be aware that it will change before stabilizing.\n\n## Usage\n\n```sh\ngleam add comet\n```\n```gleam\nimport comet.{attribute, debug, info, warning, error}\nimport comet/level.{Debug}\n  \ntype LogAttribute {\n  Service(String)\n  Latency(Float)\n  StatusCode(Int)\n  Success(Bool)\n  Err(String)\n}\n\npub fn main() {\n  // intitialize the underlying logger settings\n  comet.new()\n  |&gt; comet.level(Debug)\n  |&gt; comet.configure\n\n  let log = comet.log()\n    |&gt; attribute(Service(&quot;comet&quot;))\n\n  log\n  |&gt; debug(&quot;did this work? hi mom&quot;)\n\n  log\n  |&gt; attribute(Latency(24.2))\n  |&gt; attribute(StatusCode(200))\n  |&gt; attribute(Success(True))\n  |&gt; info(&quot;access log&quot;)\n\n  log\n  |&gt; attribute(Latency(102.2))\n  |&gt; attribute(StatusCode(400))\n  |&gt; attribute(Err(&quot;input not accepted&quot;))\n  |&gt; attribute(Success(False))\n  |&gt; warning(&quot;access log&quot;)\n\n  log\n  |&gt; attribute(Latency(402.0))\n  |&gt; attribute(StatusCode(500))\n  |&gt; attribute(Err(&quot;database connection error&quot;))\n  |&gt; attribute(Success(False))\n  |&gt; error(&quot;access log&quot;)\n}\n```\n\noutputs the log\n```\nlevel=debug time=2024-04-28T06:58:37.879Z attributes=[Service(&quot;comet&quot;)] msg=did this work? hi mom\nlevel=info time=2024-04-28T06:58:37.883Z attributes=[Service(&quot;comet&quot;), Latency(24.2), StatusCode(200), Success(True)] msg=access log\nlevel=warn time=2024-04-28T06:58:37.883Z attributes=[Success(False), AnError(&quot;input not accepted&quot;), StatusCode(400), Latency(102.2), Service(&quot;comet&quot;)] msg=access log\nlevel=error time=2024-04-28T06:58:37.884Z attributes=[Success(False), AnError(&quot;database connection error&quot;), StatusCode(500), Latency(402.1), Service(&quot;comet&quot;)] msg=access log\n```\n\n## JSON Formatted Logs\n```gleam\nimport comet.{info}\nimport gleam/json\n\n// Note: It&#39;s recommended to create a single Attribute Type for your application that contains\n// all necessary records for attributes, otherwise it will be impossible to serialize\n// fields for structured logging.\ntype LogAttribute {\n  Service(String)\n  Success(Bool)\n}\n\nfn attribute_serializer(a: Attribute) -&gt; #(String, json.Json) {\n  case a {\n    Service(value) -&gt; #(&quot;service&quot;, json.string(value))\n    Latency(value) -&gt; #(&quot;latency&quot;, json.float(value))\n    StatusCode(value) -&gt; #(&quot;statusCode&quot;, json.int(value))\n    Success(value) -&gt; #(&quot;success&quot;, json.bool(value))\n    AnError(value) -&gt; #(&quot;error&quot;, json.string(value))\n  }\n}\n\nfn main() {\n  comet.new()\n  |&gt; comet.with_formatter(comet.json_formatter(attribute_serializer))\n  |&gt; configure\n\n  comet.log()\n  |&gt; attributes([Service(&quot;comet&quot;), Success(True)])\n  |&gt; info(&quot;Halley&#39;s Comet returns in 2061&quot;)\n}\n```\n\nwill output the logs:\n```json\n{&quot;msg&quot;:&quot;Halley&#39;s Comet returns in 2061&quot;,&quot;time&quot;:&quot;2024-04-28T07:04:01.600Z&quot;,&quot;level&quot;:&quot;info&quot;,&quot;service&quot;:&quot;comet&quot;,&quot;success&quot;:true}\n```\nFurther documentation can be found at &lt;https://hexdocs.pm/comet&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"comet/level","title":"Level","content":"pub type Level {\n  Debug\n  Info\n  Warning\n  Error\n}\n\nDebug\n\n\nInfo\n\n\nWarning\n\n\nError\n\n\nSynonyms:\ncomet/level.Level\ncomet/level Level","url":"comet/level.html#Level"},{"doc":"comet/level","title":"level_priority","content":"pub fn level_priority(level: Level) -&gt; Int\n\nSynonyms:\ncomet/level.level_priority\ncomet/level level_priority","url":"comet/level.html#level_priority"},{"doc":"comet/level","title":"level_text","content":"pub fn level_text(level: Level) -&gt; String\n\nSynonyms:\ncomet/level.level_text\ncomet/level level_text","url":"comet/level.html#level_text"},{"doc":"comet/level","title":"level_text_ansi","content":"pub fn level_text_ansi(level: Level) -&gt; String\n\nSynonyms:\ncomet/level.level_text_ansi\ncomet/level level_text_ansi","url":"comet/level.html#level_text_ansi"},{"doc":"comet/level","title":"comet/level","content":"","url":"comet/level.html"},{"doc":"comet","title":"AttributeJsonSerializer","content":"pub type AttributeJsonSerializer(t) =\n  fn(t) -&gt; #(String, json.Json)\n\n\nSynonyms:\ncomet.AttributeJsonSerializer\ncomet AttributeJsonSerializer","url":"comet.html#AttributeJsonSerializer"},{"doc":"comet","title":"Entry","content":"pub type Entry(t) {\n  Entry(level: Level, message: String, metadata: Metadata(t))\n}\n  Entry is a log entry containing the log level, message, and metadata. This will be provided to\n the log formatter to be converted into a string.\nEntry(level: Level, message: String, metadata: Metadata(t))\n\n\nSynonyms:\ncomet.Entry\ncomet Entry","url":"comet.html#Entry"},{"doc":"comet","title":"Formatter","content":"pub type Formatter(t) =\n  fn(Context(t), Entry(t)) -&gt; String\n Formatter is called by the logger to format the log entry into a string before it is sent to the\n log handler. The formatter is passed the context and the log entry and should return a string.\n The formatter is optional, if one is not provided than the default formatter is used.\n\nSynonyms:\ncomet.Formatter\ncomet Formatter","url":"comet.html#Formatter"},{"doc":"comet","title":"Handler","content":"pub type Handler =\n  fn(String) -&gt; Nil\n Handlers are functions which receive a formatted string to be sent to the log destination.\n The default handler emits logs to the console or standard_io in the case of the erlang backend.\n Additional handlers can be added to the logger to send logs to other destinations, such as shipping\n logs to a remote server or writing logs to a file.\n\nSynonyms:\ncomet.Handler\ncomet Handler","url":"comet.html#Handler"},{"doc":"comet","title":"LevelTextFn","content":"pub type LevelTextFn =\n  fn(Level) -&gt; String\n LevelTextFn can be provided to the log context to override the level names in logs\n\nSynonyms:\ncomet.LevelTextFn\ncomet LevelTextFn","url":"comet.html#LevelTextFn"},{"doc":"comet","title":"Metadata","content":"pub type Metadata(t) =\n  List(t)\n Metadata is a list of attributes that can be attached to a log entry.\n\nSynonyms:\ncomet.Metadata\ncomet Metadata","url":"comet.html#Metadata"},{"doc":"comet","title":"attribute","content":"pub fn attribute(md: List(a), attribute: a) -&gt; List(a)\n Add an attribute to the metadata.\nSynonyms:\ncomet.attribute\ncomet attribute","url":"comet.html#attribute"},{"doc":"comet","title":"attributes","content":"pub fn attributes(md: List(a), attributes: List(a)) -&gt; List(a)\n Append a list of attributes to the metadata.\nSynonyms:\ncomet.attributes\ncomet attributes","url":"comet.html#attributes"},{"doc":"comet","title":"configure","content":"pub fn configure(ctx: Context(a)) -&gt; Context(a)\n configure is used to initialize the global logger settings. It should be called once at the\n start of the application. You should not call it again after the logger has been initialized as\n it will overwrite the global erlang and javascript logger settings.\nSynonyms:\ncomet.configure\ncomet configure","url":"comet.html#configure"},{"doc":"comet","title":"debug","content":"pub fn debug(md: List(a), msg: String) -&gt; Nil\n log a message at the debug level\nSynonyms:\ncomet.debug\ncomet debug","url":"comet.html#debug"},{"doc":"comet","title":"error","content":"pub fn error(md: List(a), msg: String) -&gt; Nil\n log a message at the warning level\n log a message at the error level\nSynonyms:\ncomet.error\ncomet error","url":"comet.html#error"},{"doc":"comet","title":"get_formatter","content":"pub fn get_formatter(\n  ctx: Context(a),\n) -&gt; Option(fn(Context(a), Entry(a)) -&gt; String)\n\nSynonyms:\ncomet.get_formatter\ncomet get_formatter","url":"comet.html#get_formatter"},{"doc":"comet","title":"get_handler","content":"pub fn get_handler(ctx: Context(a)) -&gt; Option(fn(String) -&gt; Nil)\n\nSynonyms:\ncomet.get_handler\ncomet get_handler","url":"comet.html#get_handler"},{"doc":"comet","title":"info","content":"pub fn info(md: List(a), msg: String) -&gt; Nil\n log a message at the debug level\n log a message at the info level\nSynonyms:\ncomet.info\ncomet info","url":"comet.html#info"},{"doc":"comet","title":"json_formatter","content":"pub fn json_formatter(\n  serializer: fn(a) -&gt; #(String, Json),\n) -&gt; fn(Context(a), Entry(a)) -&gt; String\n\nSynonyms:\ncomet.json_formatter\ncomet json_formatter","url":"comet.html#json_formatter"},{"doc":"comet","title":"log","content":"pub fn log() -&gt; List(a)\n creates a new leg entry builder.\nSynonyms:\ncomet.log\ncomet log","url":"comet.html#log"},{"doc":"comet","title":"new","content":"pub fn new() -&gt; Context(a)\n new creates a new logger context with default settings.\n The default settings are:\n - level_text: debug, info, warn, error\n - formatter: None (uses the backend default formatter)\n - min_level: Info\nSynonyms:\ncomet.new\ncomet new","url":"comet.html#new"},{"doc":"comet","title":"set_handler","content":"pub fn set_handler(\n  ctx: Context(a),\n  name: String,\n  handler: fn(String) -&gt; Nil,\n) -&gt; Nil\n Set the context&#39;s handler to a custom Handler.\nSynonyms:\ncomet.set_handler\ncomet set_handler","url":"comet.html#set_handler"},{"doc":"comet","title":"text_formatter","content":"pub fn text_formatter(ctx: Context(a), entry: Entry(a)) -&gt; String\n This is the standard text formatter for logs. It will format the log entry into a string\nSynonyms:\ncomet.text_formatter\ncomet text_formatter","url":"comet.html#text_formatter"},{"doc":"comet","title":"timestamp","content":"pub fn timestamp(ctx: Context(a), active: Bool) -&gt; Context(a)\n togle timestamps\nSynonyms:\ncomet.timestamp\ncomet timestamp","url":"comet.html#timestamp"},{"doc":"comet","title":"warning","content":"pub fn warning(md: List(a), msg: String) -&gt; Nil\n log a message at the info level\n log a message at the warning level\nSynonyms:\ncomet.warning\ncomet warning","url":"comet.html#warning"},{"doc":"comet","title":"with_formatter","content":"pub fn with_formatter(\n  ctx: Context(a),\n  formatter: fn(Context(a), Entry(a)) -&gt; String,\n) -&gt; Context(a)\n provide a custom formatter to format log entries\nSynonyms:\ncomet.with_formatter\ncomet with_formatter","url":"comet.html#with_formatter"},{"doc":"comet","title":"with_level","content":"pub fn with_level(ctx: Context(a), level: Level) -&gt; Context(a)\n set the log level for the logger\nSynonyms:\ncomet.with_level\ncomet with_level","url":"comet.html#with_level"},{"doc":"comet","title":"with_level_text","content":"pub fn with_level_text(\n  ctx: Context(a),\n  func: fn(Level) -&gt; String,\n) -&gt; Context(a)\n Provide a function to override the log level names emitted in logs \nSynonyms:\ncomet.with_level_text\ncomet with_level_text","url":"comet.html#with_level_text"},{"doc":"comet","title":"comet","content":" Create a gleaming trail of application logs. ","url":"comet.html"},{"doc":"comet/comet_handler","title":"atom","content":"pub fn atom(name: String) -&gt; Atom\n\nSynonyms:\ncomet/comet_handler.atom\ncomet/comet_handler atom","url":"comet/comet_handler.html#atom"},{"doc":"comet/comet_handler","title":"format","content":"pub fn format(\n  log: Dict(Atom, Dynamic),\n  config: Dict(Atom, Context(a)),\n) -&gt; Charlist\n Format is used for formatting log entries into strings. by the default erlang logger.\nSynonyms:\ncomet/comet_handler.format\ncomet/comet_handler format","url":"comet/comet_handler.html#format"},{"doc":"comet/comet_handler","title":"log","content":"pub fn log(\n  event: Dict(Atom, Dynamic),\n  config: Dict(Atom, Context(a)),\n) -&gt; Nil\n\nSynonyms:\ncomet/comet_handler.log\ncomet/comet_handler log","url":"comet/comet_handler.html#log"},{"doc":"comet/comet_handler","title":"comet/comet_handler","content":"","url":"comet/comet_handler.html"}]);